# frozen_string_literal: true

require 'httparty'

module CSVPP
  class FormatsClient
    include HTTParty

    DEFAULT_HOST = 'http://formats.iapps.swissdrg.local'

    def initialize(host: DEFAULT_HOST)
      self.class.base_uri ENV['FORMATS_HOST'] || host
    end

    # @return [String] e.g. "http://formats.iapps.swissdrg.local"
    def base_uri
      self.class.base_uri
    end

    # @return [Array<Format>]
    def formats
      self.class.get('/api/formats').map { |hash| Format.new(hash) }
    end

    # @param name [String]
    # @return [Format]
    def format(name)
      response = self.class.get("/api/formats/#{name}")

      if (error = response['error'])
        raise ArgumentError, %{#{error} "#{name}"}
      end

      Format.new(response)
    end
  end
end
