# frozen_string_literal: true

require 'sequel'

module CSVPP
  # Imports data into an Sqlite database.
  class SqliteImporter
    attr_reader :format, :data, :db

    # @param format [Format]
    # @param db_path [String]
    def initialize(format:, db_path:)
      @format = format
      @db = Sequel.sqlite(db_path)

      @db.drop_table? :data
      @db.create_table :data do
        Int :line_number

        format.var_names.each do |var|
          type = format.type(var)

          if type.start_with?('array')
            type = 'String'
          else
            type.capitalize
          end

          send(type, var)
        end
      end

      @data = @db[:data]
    end

    # @param input [String] input string
    def import(input)
      Parser.parse_str(
        input: input,
        format: format,
        convert_type: false
      ) do |attr|
        data.insert(attr)
      end
    end
  end
end
